## Berkeley Autolab Core Modules
[![pypi](https://img.shields.io/pypi/v/autolab-core.svg)](https://pypi.org/project/autolab-core/) [![python-versions](https://img.shields.io/pypi/pyversions/autolab-core.svg)](https://pypi.org/project/autolab-core/) [![status](https://github.com/BerkeleyAutomation/autolab_core/workflows/Release%20Autolab%20Core/badge.svg)](https://github.com/BerkeleyAutomation/autolab_core/actions) [![style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

This module contains a set of useful utilities for robotic tasks.
View the install guide and API documentation [here](https://BerkeleyAutomation.github.io/autolab_core).

NOTE: As of May 3, 2021, this package has dropped support for Python versions 3.5 and lower, as these versions have reached their EOL. If you wish to use older Python versions, please use the 0.x.x series of tags. Additionally, many modules from the `autolab_perception` package have been migrated here to reduce confusion.

NOTE: As of June 18, 2017, this package has been renamed from `core` to `autolab_core` to prevent naming conflicts.
If you wish to use the old version named `core`, please checkout the branch `pre_name_change`.
However, no further updates will be pushed to this branch.
